==> _private_core_network-1.2.69.tar.gz: lib/network_resources/model/appointment_ticket_model.dart <==
class TicketInfoModel {
  int? timeStart;
  int? realStart;
  int? userId;
  int? averageTime;
  String? accessCode;
  String? uniqueId;
  int? updatedAt;
  int? serviceId;
  int? timeStop;
  int? realStop;
  int? status;
  int? createdAt;
  String? eventUniqueId;
  String? ticketUniqueId;
  String? proDisplayName;
  String? proUniqueId;
  int? commissionId;
  int? timeRemaining;

  TicketInfoModel(
      {this.timeStart,
      this.realStart,
      this.timeRemaining,
      this.userId,
      this.averageTime,
      this.accessCode,
      this.uniqueId,
      this.updatedAt,
      this.serviceId,
      this.timeStop,
      this.realStop,
      this.status,
      this.eventUniqueId,
      this.ticketUniqueId,
      this.createdAt,
      this.commissionId,
      this.proDisplayName,
      this.proUniqueId});

  int? get total {
    if (timeStop != null && timeStart != null) return timeStop! - timeStart!;
  }

  TicketInfoModel.fromJson(Map<String, dynamic> json) {
    timeStart = json['timeStart'] ?? 0;
    timeRemaining = json['timeRemaining'];
    realStart = json['realStart'];
    userId = json['userId'] ?? 0;
    averageTime = json['averageTime'] ?? 0;
    accessCode = json['accessCode'] ?? '';
    uniqueId = json['uniqueId'] ?? '';
    updatedAt = json['updatedAt'];
    serviceId = json['serviceId'];
    timeStop = json['timeStop'];
    realStop = json['realStop'];
    status = json['status'] ?? 0;
    createdAt = json['createdAt'];
    eventUniqueId = json['eventUniqueId'] ?? '';
    ticketUniqueId = json['ticketUniqueId'] ?? '';
    proDisplayName = json['proDisplayName'] ?? '';
    proUniqueId = json['proUniqueId'] ?? '';
    commissionId = json['commissionId'] ?? 0;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['timeRemaining'] = this.timeRemaining;
    data['timeStart'] = this.timeStart;
    data['realStart'] = this.realStart;
    data['userId'] = this.userId;
    data['averageTime'] = this.averageTime;
    data['accessCode'] = this.accessCode;
    data['uniqueId'] = this.uniqueId;
    data['updatedAt'] = this.updatedAt;
    data['serviceId'] = this.serviceId;
    data['timeStop'] = this.timeStop;
    data['realStop'] = this.realStop;
    data['status'] = this.status;
    data['createdAt'] = this.createdAt;
    data['eventUniqueId'] = this.eventUniqueId;
    data['ticketUniqueId'] = this.ticketUniqueId;
    return data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/appointment_ticket_model.dart <==
class TicketInfoModel {
  int? timeStart;
  int? realStart;
  int? userId;
  int? averageTime;
  String? accessCode;
  String? uniqueId;
  int? updatedAt;
  int? serviceId;
  int? timeStop;
  int? realStop;
  int? status;
  int? createdAt;
  String? eventUniqueId;
  String? ticketUniqueId;
  String? proDisplayName;
  String? proUniqueId;
  int? commissionId;
  int? timeRemaining;

  TicketInfoModel(
      {this.timeStart,
      this.realStart,
      this.timeRemaining,
      this.userId,
      this.averageTime,
      this.accessCode,
      this.uniqueId,
      this.updatedAt,
      this.serviceId,
      this.timeStop,
      this.realStop,
      this.status,
      this.eventUniqueId,
      this.ticketUniqueId,
      this.createdAt,
      this.commissionId,
      this.proDisplayName,
      this.proUniqueId});

  int? get total {
    if (timeStop != null && timeStart != null) return timeStop! - timeStart!;
    return null;
  }

  TicketInfoModel.fromJson(Map<String, dynamic> json) {
    timeStart = json['timeStart'] ?? 0;
    timeRemaining = json['timeRemaining'];
    realStart = json['realStart'];
    userId = json['userId'] ?? 0;
    averageTime = json['averageTime'] ?? 0;
    accessCode = json['accessCode'] ?? '';
    uniqueId = json['uniqueId'] ?? '';
    updatedAt = json['updatedAt'];
    serviceId = json['serviceId'];
    timeStop = json['timeStop'];
    realStop = json['realStop'];
    status = json['status'] ?? 0;
    createdAt = json['createdAt'];
    eventUniqueId = json['eventUniqueId'] ?? '';
    ticketUniqueId = json['ticketUniqueId'] ?? '';
    proDisplayName = json['proDisplayName'] ?? '';
    proUniqueId = json['proUniqueId'] ?? '';
    commissionId = json['commissionId'] ?? 0;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['timeRemaining'] = timeRemaining;
    data['timeStart'] = timeStart;
    data['realStart'] = realStart;
    data['userId'] = userId;
    data['averageTime'] = averageTime;
    data['accessCode'] = accessCode;
    data['uniqueId'] = uniqueId;
    data['updatedAt'] = updatedAt;
    data['serviceId'] = serviceId;
    data['timeStop'] = timeStop;
    data['realStop'] = realStop;
    data['status'] = status;
    data['createdAt'] = createdAt;
    data['eventUniqueId'] = eventUniqueId;
    data['ticketUniqueId'] = ticketUniqueId;
    return data;
  }
}
